% remove_event_data() - Remove continuous data for the duration
% of specific events.
% Useful for removing intervals that are defined by individual markers
% and a number of points (duration).
% Also removes other markers within the removed time interval.
%
% Useful to delete Brain Vision Analyzer's bad data intervals.
% Outputs a continuous EEG file.
% You can access the event types of your EEG file by running 'unique({EEG.event.type})'
%
% This function doesn't respect phase activity! If you want to use
% this function and still compute phase information, then don't do it
% around epochs that contain the event "boundary".
%
% Usage:
%   >> OUTEEG = eeglab_remove_event_data (EEG, typerange);
%
% Inputs:
%   EEG        - Input dataset. Not tested for epoched data.
%   typerange  - Cell array of event types to time lock to.
%                (Note: An event field called 'type' must be defined in 
%                the 'EEG.event' structure).
% Outputs:
%   OUTEEG     - output dataset

% Copyright (C) 2017 Gonalo Sampaio, gsampaio@wesleyan.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% eegplugin_remove_event_data()
function eegplugin_remove_event_data (fig, try_strings, catch_strings) ;

% create menu
toolsmenu = findobj(fig, 'tag', 'tools');
uimenu( toolsmenu, 'label', 'Remove continuous data interval', 'callback', [ 'EEG = pop_remove_event_data(EEG); [ALLEEG EEG CURRENTSET] = eeg_store(ALLEEG, EEG, CURRENTSET);' ]);